Struct aws_sdk_backup::client::Client [−][src]
pub struct Client<C = DynConnector, M = AwsMiddleware, R = Standard> { /* fields omitted */ }Expand description
An ergonomic service client for CryoControllerUserManager.
This client allows ergonomic access to a CryoControllerUserManager-shaped service.
Each method corresponds to an endpoint defined in the service’s Smithy model,
and the request and response shapes are auto-generated from that same model.
Using a Client
Once you have a client set up, you can access the service’s endpoints
by calling the appropriate method on Client. Each such method
returns a request builder for that endpoint, with methods for setting
the various fields of the request. Once your request is complete, use
the send method to send the request. send returns a future, which
you then have to .await to get the service’s response.
Implementations
impl<C, M, R> Client<C, M, R> where
C: SmithyConnector,
M: SmithyMiddleware<C>,
R: NewRequestPolicy,
impl<C, M, R> Client<C, M, R> where
C: SmithyConnector,
M: SmithyMiddleware<C>,
R: NewRequestPolicy,
Constructs a fluent builder for the CreateBackupPlan operation.
See CreateBackupPlan for more information about the
operation and its arguments.
Constructs a fluent builder for the CreateBackupSelection operation.
See CreateBackupSelection for more information about the
operation and its arguments.
Constructs a fluent builder for the CreateBackupVault operation.
See CreateBackupVault for more information about the
operation and its arguments.
Constructs a fluent builder for the CreateFramework operation.
See CreateFramework for more information about the
operation and its arguments.
Constructs a fluent builder for the CreateReportPlan operation.
See CreateReportPlan for more information about the
operation and its arguments.
Constructs a fluent builder for the DeleteBackupPlan operation.
See DeleteBackupPlan for more information about the
operation and its arguments.
Constructs a fluent builder for the DeleteBackupSelection operation.
See DeleteBackupSelection for more information about the
operation and its arguments.
Constructs a fluent builder for the DeleteBackupVault operation.
See DeleteBackupVault for more information about the
operation and its arguments.
Constructs a fluent builder for the DeleteBackupVaultAccessPolicy operation.
See DeleteBackupVaultAccessPolicy for more information about the
operation and its arguments.
pub fn delete_backup_vault_lock_configuration(
&self
) -> DeleteBackupVaultLockConfiguration<C, M, R>
pub fn delete_backup_vault_lock_configuration(
&self
) -> DeleteBackupVaultLockConfiguration<C, M, R>
Constructs a fluent builder for the DeleteBackupVaultLockConfiguration operation.
See DeleteBackupVaultLockConfiguration for more information about the
operation and its arguments.
Constructs a fluent builder for the DeleteBackupVaultNotifications operation.
See DeleteBackupVaultNotifications for more information about the
operation and its arguments.
Constructs a fluent builder for the DeleteFramework operation.
See DeleteFramework for more information about the
operation and its arguments.
Constructs a fluent builder for the DeleteRecoveryPoint operation.
See DeleteRecoveryPoint for more information about the
operation and its arguments.
Constructs a fluent builder for the DeleteReportPlan operation.
See DeleteReportPlan for more information about the
operation and its arguments.
Constructs a fluent builder for the DescribeBackupJob operation.
See DescribeBackupJob for more information about the
operation and its arguments.
Constructs a fluent builder for the DescribeBackupVault operation.
See DescribeBackupVault for more information about the
operation and its arguments.
Constructs a fluent builder for the DescribeCopyJob operation.
See DescribeCopyJob for more information about the
operation and its arguments.
Constructs a fluent builder for the DescribeFramework operation.
See DescribeFramework for more information about the
operation and its arguments.
Constructs a fluent builder for the DescribeGlobalSettings operation.
See DescribeGlobalSettings for more information about the
operation and its arguments.
Constructs a fluent builder for the DescribeProtectedResource operation.
See DescribeProtectedResource for more information about the
operation and its arguments.
Constructs a fluent builder for the DescribeRecoveryPoint operation.
See DescribeRecoveryPoint for more information about the
operation and its arguments.
Constructs a fluent builder for the DescribeRegionSettings operation.
See DescribeRegionSettings for more information about the
operation and its arguments.
Constructs a fluent builder for the DescribeReportJob operation.
See DescribeReportJob for more information about the
operation and its arguments.
Constructs a fluent builder for the DescribeReportPlan operation.
See DescribeReportPlan for more information about the
operation and its arguments.
Constructs a fluent builder for the DescribeRestoreJob operation.
See DescribeRestoreJob for more information about the
operation and its arguments.
Constructs a fluent builder for the DisassociateRecoveryPoint operation.
See DisassociateRecoveryPoint for more information about the
operation and its arguments.
Constructs a fluent builder for the ExportBackupPlanTemplate operation.
See ExportBackupPlanTemplate for more information about the
operation and its arguments.
Constructs a fluent builder for the GetBackupPlan operation.
See GetBackupPlan for more information about the
operation and its arguments.
Constructs a fluent builder for the GetBackupPlanFromJSON operation.
See GetBackupPlanFromJSON for more information about the
operation and its arguments.
Constructs a fluent builder for the GetBackupPlanFromTemplate operation.
See GetBackupPlanFromTemplate for more information about the
operation and its arguments.
Constructs a fluent builder for the GetBackupSelection operation.
See GetBackupSelection for more information about the
operation and its arguments.
Constructs a fluent builder for the GetBackupVaultAccessPolicy operation.
See GetBackupVaultAccessPolicy for more information about the
operation and its arguments.
Constructs a fluent builder for the GetBackupVaultNotifications operation.
See GetBackupVaultNotifications for more information about the
operation and its arguments.
Constructs a fluent builder for the GetRecoveryPointRestoreMetadata operation.
See GetRecoveryPointRestoreMetadata for more information about the
operation and its arguments.
Constructs a fluent builder for the GetSupportedResourceTypes operation.
See GetSupportedResourceTypes for more information about the
operation and its arguments.
Constructs a fluent builder for the ListBackupJobs operation.
See ListBackupJobs for more information about the
operation and its arguments.
Constructs a fluent builder for the ListBackupPlans operation.
See ListBackupPlans for more information about the
operation and its arguments.
Constructs a fluent builder for the ListBackupPlanTemplates operation.
See ListBackupPlanTemplates for more information about the
operation and its arguments.
Constructs a fluent builder for the ListBackupPlanVersions operation.
See ListBackupPlanVersions for more information about the
operation and its arguments.
Constructs a fluent builder for the ListBackupSelections operation.
See ListBackupSelections for more information about the
operation and its arguments.
Constructs a fluent builder for the ListBackupVaults operation.
See ListBackupVaults for more information about the
operation and its arguments.
Constructs a fluent builder for the ListCopyJobs operation.
See ListCopyJobs for more information about the
operation and its arguments.
Constructs a fluent builder for the ListFrameworks operation.
See ListFrameworks for more information about the
operation and its arguments.
Constructs a fluent builder for the ListProtectedResources operation.
See ListProtectedResources for more information about the
operation and its arguments.
pub fn list_recovery_points_by_backup_vault(
&self
) -> ListRecoveryPointsByBackupVault<C, M, R>
pub fn list_recovery_points_by_backup_vault(
&self
) -> ListRecoveryPointsByBackupVault<C, M, R>
Constructs a fluent builder for the ListRecoveryPointsByBackupVault operation.
See ListRecoveryPointsByBackupVault for more information about the
operation and its arguments.
Constructs a fluent builder for the ListRecoveryPointsByResource operation.
See ListRecoveryPointsByResource for more information about the
operation and its arguments.
Constructs a fluent builder for the ListReportJobs operation.
See ListReportJobs for more information about the
operation and its arguments.
Constructs a fluent builder for the ListReportPlans operation.
See ListReportPlans for more information about the
operation and its arguments.
Constructs a fluent builder for the ListRestoreJobs operation.
See ListRestoreJobs for more information about the
operation and its arguments.
Constructs a fluent builder for the ListTags operation.
See ListTags for more information about the
operation and its arguments.
Constructs a fluent builder for the PutBackupVaultAccessPolicy operation.
See PutBackupVaultAccessPolicy for more information about the
operation and its arguments.
Constructs a fluent builder for the PutBackupVaultLockConfiguration operation.
See PutBackupVaultLockConfiguration for more information about the
operation and its arguments.
Constructs a fluent builder for the PutBackupVaultNotifications operation.
See PutBackupVaultNotifications for more information about the
operation and its arguments.
Constructs a fluent builder for the StartBackupJob operation.
See StartBackupJob for more information about the
operation and its arguments.
Constructs a fluent builder for the StartCopyJob operation.
See StartCopyJob for more information about the
operation and its arguments.
Constructs a fluent builder for the StartReportJob operation.
See StartReportJob for more information about the
operation and its arguments.
Constructs a fluent builder for the StartRestoreJob operation.
See StartRestoreJob for more information about the
operation and its arguments.
Constructs a fluent builder for the StopBackupJob operation.
See StopBackupJob for more information about the
operation and its arguments.
Constructs a fluent builder for the TagResource operation.
See TagResource for more information about the
operation and its arguments.
Constructs a fluent builder for the UntagResource operation.
See UntagResource for more information about the
operation and its arguments.
Constructs a fluent builder for the UpdateBackupPlan operation.
See UpdateBackupPlan for more information about the
operation and its arguments.
Constructs a fluent builder for the UpdateFramework operation.
See UpdateFramework for more information about the
operation and its arguments.
Constructs a fluent builder for the UpdateGlobalSettings operation.
See UpdateGlobalSettings for more information about the
operation and its arguments.
Constructs a fluent builder for the UpdateRecoveryPointLifecycle operation.
See UpdateRecoveryPointLifecycle for more information about the
operation and its arguments.
Constructs a fluent builder for the UpdateRegionSettings operation.
See UpdateRegionSettings for more information about the
operation and its arguments.
Constructs a fluent builder for the UpdateReportPlan operation.
See UpdateReportPlan for more information about the
operation and its arguments.
Creates a client with the given service config and connector override.