Struct aws_sdk_backup::input::list_frameworks_input::Builder [−][src]
#[non_exhaustive]pub struct Builder { /* fields omitted */ }Expand description
A builder for ListFrameworksInput
Implementations
The number of desired results from 1 to 1000. Optional. If unspecified, the query will return 1 MB of data.
The number of desired results from 1 to 1000. Optional. If unspecified, the query will return 1 MB of data.
An identifier that was returned from the previous call to this operation, which can be used to return the next set of items in the list.
An identifier that was returned from the previous call to this operation, which can be used to return the next set of items in the list.
Consumes the builder and constructs a ListFrameworksInput