Struct aws_sdk_backup::input::ListBackupJobsInput [−][src]
#[non_exhaustive]pub struct ListBackupJobsInput {
pub next_token: Option<String>,
pub max_results: Option<i32>,
pub by_resource_arn: Option<String>,
pub by_state: Option<BackupJobState>,
pub by_backup_vault_name: Option<String>,
pub by_created_before: Option<Instant>,
pub by_created_after: Option<Instant>,
pub by_resource_type: Option<String>,
pub by_account_id: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.next_token: Option<String>The next item following a partial list of returned items. For example, if a request is
made to return maxResults number of items, NextToken allows you
to return more items in your list starting at the location pointed to by the next
token.
max_results: Option<i32>The maximum number of items to be returned.
by_resource_arn: Option<String>Returns only backup jobs that match the specified resource Amazon Resource Name (ARN).
by_state: Option<BackupJobState>Returns only backup jobs that are in the specified state.
by_backup_vault_name: Option<String>Returns only backup jobs that will be stored in the specified backup vault. Backup vaults are identified by names that are unique to the account used to create them and the Amazon Web Services Region where they are created. They consist of lowercase letters, numbers, and hyphens.
by_created_before: Option<Instant>Returns only backup jobs that were created before the specified date.
by_created_after: Option<Instant>Returns only backup jobs that were created after the specified date.
by_resource_type: Option<String>Returns only backup jobs for the specified resources:
-
DynamoDBfor Amazon DynamoDB -
EBSfor Amazon Elastic Block Store -
EC2for Amazon Elastic Compute Cloud -
EFSfor Amazon Elastic File System -
RDSfor Amazon Relational Database Service -
Aurorafor Amazon Aurora -
Storage Gatewayfor Storage Gateway
by_account_id: Option<String>The account ID to list the jobs from. Returns only backup jobs associated with the specified account ID.
If used from an Organizations management account, passing * returns
all jobs across the organization.
Implementations
pub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<ListBackupJobs, AwsErrorRetryPolicy>, BuildError>
pub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<ListBackupJobs, AwsErrorRetryPolicy>, BuildError>
Consumes the builder and constructs an Operation<ListBackupJobs>
Creates a new builder-style object to manufacture ListBackupJobsInput
The next item following a partial list of returned items. For example, if a request is
made to return maxResults number of items, NextToken allows you
to return more items in your list starting at the location pointed to by the next
token.
The maximum number of items to be returned.
Returns only backup jobs that match the specified resource Amazon Resource Name (ARN).
Returns only backup jobs that are in the specified state.
Returns only backup jobs that will be stored in the specified backup vault. Backup vaults are identified by names that are unique to the account used to create them and the Amazon Web Services Region where they are created. They consist of lowercase letters, numbers, and hyphens.
Returns only backup jobs that were created before the specified date.
Returns only backup jobs that were created after the specified date.
Returns only backup jobs for the specified resources:
-
DynamoDBfor Amazon DynamoDB -
EBSfor Amazon Elastic Block Store -
EC2for Amazon Elastic Compute Cloud -
EFSfor Amazon Elastic File System -
RDSfor Amazon Relational Database Service -
Aurorafor Amazon Aurora -
Storage Gatewayfor Storage Gateway
The account ID to list the jobs from. Returns only backup jobs associated with the specified account ID.
If used from an Organizations management account, passing * returns
all jobs across the organization.