Struct aws_sdk_backup::input::StartRestoreJobInput [−][src]
#[non_exhaustive]pub struct StartRestoreJobInput {
pub recovery_point_arn: Option<String>,
pub metadata: Option<HashMap<String, String>>,
pub iam_role_arn: Option<String>,
pub idempotency_token: Option<String>,
pub resource_type: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.recovery_point_arn: Option<String>An ARN that uniquely identifies a recovery point; for example,
arn:aws:backup:us-east-1:123456789012:recovery-point:1EB3B5E7-9EB0-435A-A80B-108B488B0D45.
metadata: Option<HashMap<String, String>>A set of metadata key-value pairs. Contains information, such as a resource name, required to restore a recovery point.
You can get configuration metadata about a resource at the time it was backed up by
calling GetRecoveryPointRestoreMetadata. However, values in addition to those
provided by GetRecoveryPointRestoreMetadata might be required to restore a
resource. For example, you might need to provide a new resource name if the original
already exists.
You need to specify specific metadata to restore an Amazon Elastic File System (Amazon EFS) instance:
-
file-system-id: The ID of the Amazon EFS file system that is backed up by Backup. Returned inGetRecoveryPointRestoreMetadata. -
Encrypted: A Boolean value that, if true, specifies that the file system is encrypted. IfKmsKeyIdis specified,Encryptedmust be set totrue. -
KmsKeyId: Specifies the Amazon Web Services KMS key that is used to encrypt the restored file system. You can specify a key from another Amazon Web Services account provided that key it is properly shared with your account via Amazon Web Services KMS. -
PerformanceMode: Specifies the throughput mode of the file system. -
CreationToken: A user-supplied value that ensures the uniqueness (idempotency) of the request. -
newFileSystem: A Boolean value that, if true, specifies that the recovery point is restored to a new Amazon EFS file system. -
ItemsToRestore: An array of one to five strings where each string is a file path. UseItemsToRestoreto restore specific files or directories rather than the entire file system. This parameter is optional. For example,"itemsToRestore":"[\"/my.test\"]".
iam_role_arn: Option<String>The Amazon Resource Name (ARN) of the IAM role that Backup uses to create
the target recovery point; for example,
arn:aws:iam::123456789012:role/S3Access.
idempotency_token: Option<String>A customer-chosen string that you can use to distinguish between otherwise identical
calls to StartRestoreJob. Retrying a successful request with the same
idempotency token results in a success message with no action taken.
resource_type: Option<String>Starts a job to restore a recovery point for one of the following resources:
-
DynamoDBfor Amazon DynamoDB -
EBSfor Amazon Elastic Block Store -
EC2for Amazon Elastic Compute Cloud -
EFSfor Amazon Elastic File System -
RDSfor Amazon Relational Database Service -
Aurorafor Amazon Aurora -
Storage Gatewayfor Storage Gateway
Implementations
pub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<StartRestoreJob, AwsErrorRetryPolicy>, BuildError>
pub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<StartRestoreJob, AwsErrorRetryPolicy>, BuildError>
Consumes the builder and constructs an Operation<StartRestoreJob>
Creates a new builder-style object to manufacture StartRestoreJobInput
An ARN that uniquely identifies a recovery point; for example,
arn:aws:backup:us-east-1:123456789012:recovery-point:1EB3B5E7-9EB0-435A-A80B-108B488B0D45.
A set of metadata key-value pairs. Contains information, such as a resource name, required to restore a recovery point.
You can get configuration metadata about a resource at the time it was backed up by
calling GetRecoveryPointRestoreMetadata. However, values in addition to those
provided by GetRecoveryPointRestoreMetadata might be required to restore a
resource. For example, you might need to provide a new resource name if the original
already exists.
You need to specify specific metadata to restore an Amazon Elastic File System (Amazon EFS) instance:
-
file-system-id: The ID of the Amazon EFS file system that is backed up by Backup. Returned inGetRecoveryPointRestoreMetadata. -
Encrypted: A Boolean value that, if true, specifies that the file system is encrypted. IfKmsKeyIdis specified,Encryptedmust be set totrue. -
KmsKeyId: Specifies the Amazon Web Services KMS key that is used to encrypt the restored file system. You can specify a key from another Amazon Web Services account provided that key it is properly shared with your account via Amazon Web Services KMS. -
PerformanceMode: Specifies the throughput mode of the file system. -
CreationToken: A user-supplied value that ensures the uniqueness (idempotency) of the request. -
newFileSystem: A Boolean value that, if true, specifies that the recovery point is restored to a new Amazon EFS file system. -
ItemsToRestore: An array of one to five strings where each string is a file path. UseItemsToRestoreto restore specific files or directories rather than the entire file system. This parameter is optional. For example,"itemsToRestore":"[\"/my.test\"]".
The Amazon Resource Name (ARN) of the IAM role that Backup uses to create
the target recovery point; for example,
arn:aws:iam::123456789012:role/S3Access.
A customer-chosen string that you can use to distinguish between otherwise identical
calls to StartRestoreJob. Retrying a successful request with the same
idempotency token results in a success message with no action taken.
Starts a job to restore a recovery point for one of the following resources:
-
DynamoDBfor Amazon DynamoDB -
EBSfor Amazon Elastic Block Store -
EC2for Amazon Elastic Compute Cloud -
EFSfor Amazon Elastic File System -
RDSfor Amazon Relational Database Service -
Aurorafor Amazon Aurora -
Storage Gatewayfor Storage Gateway