Struct aws_sdk_backup::model::framework_control::Builder [−][src]
#[non_exhaustive]pub struct Builder { /* fields omitted */ }Expand description
A builder for FrameworkControl
Implementations
The name of a control. This name is between 1 and 256 characters.
The name of a control. This name is between 1 and 256 characters.
Appends an item to control_input_parameters.
To override the contents of this collection use set_control_input_parameters.
A list of ParameterName and ParameterValue pairs.
A list of ParameterName and ParameterValue pairs.
The scope of a control. The control scope defines what the control will evaluate. Three
examples of control scopes are: a specific backup plan, all backup plans with a specific
tag, or all backup plans. For more information, see ControlScope.
The scope of a control. The control scope defines what the control will evaluate. Three
examples of control scopes are: a specific backup plan, all backup plans with a specific
tag, or all backup plans. For more information, see ControlScope.
Consumes the builder and constructs a FrameworkControl