CreateBackupAccessPointInputBuilder

Struct CreateBackupAccessPointInputBuilder 

#[non_exhaustive]
pub struct CreateBackupAccessPointInputBuilder { /* private fields */ }
Implementations

Source

impl CreateBackupAccessPointInputBuilder

pub fn access_point_metadata( self, k: impl Into<String>, v: impl Into<String>, ) -> Self

Adds a key-value pair to access_point_metadata.

To override the contents of this collection use set_access_point_metadata.

Metadata for the backup access point. For continuous (point-in-time) recovery points, you must include an AccessPointInTime timestamp (in format 2021-11-27T03:30:27Z). The access point provides access to the content present in the backup at that specific time. You can specify any time within the continuous backup's retention period, up to the latest restorable time. For snapshot recovery points, do not include AccessPointInTime.

pub fn set_access_point_metadata( self, input: Option<HashMap<String, String>>, ) -> Self

Metadata for the backup access point. For continuous (point-in-time) recovery points, you must include an AccessPointInTime timestamp (in format 2021-11-27T03:30:27Z). The access point provides access to the content present in the backup at that specific time. You can specify any time within the continuous backup's retention period, up to the latest restorable time. For snapshot recovery points, do not include AccessPointInTime.

pub fn get_access_point_metadata(&self) -> &Option<HashMap<String, String>>

Metadata for the backup access point. For continuous (point-in-time) recovery points, you must include an AccessPointInTime timestamp (in format 2021-11-27T03:30:27Z). The access point provides access to the content present in the backup at that specific time. You can specify any time within the continuous backup's retention period, up to the latest restorable time. For snapshot recovery points, do not include AccessPointInTime.

pub fn access_point_policy(self, input: impl Into<String>) -> Self

An optional resource-based policy, in JSON format, to apply to the underlying Amazon S3 access point. The policy controls how backup data can be accessed through the access point. If you do not specify a policy, access is governed by the caller's IAM permissions. For more information, see Configuring IAM policies for using access points in the Amazon S3 User Guide.

pub fn set_access_point_policy(self, input: Option<String>) -> Self

An optional resource-based policy, in JSON format, to apply to the underlying Amazon S3 access point. The policy controls how backup data can be accessed through the access point. If you do not specify a policy, access is governed by the caller's IAM permissions. For more information, see Configuring IAM policies for using access points in the Amazon S3 User Guide.

pub fn get_access_point_policy(&self) -> &Option<String>

An optional resource-based policy, in JSON format, to apply to the underlying Amazon S3 access point. The policy controls how backup data can be accessed through the access point. If you do not specify a policy, access is governed by the caller's IAM permissions. For more information, see Configuring IAM policies for using access points in the Amazon S3 User Guide.

pub fn name(self, input: impl Into<String>) -> Self

The name of the backup access point. This name is shared with the Amazon S3 access point namespace. It must be unique within your account and Region and cannot conflict with an existing Amazon S3 access point. For more information about access point naming, see Access points naming rules, restrictions, and limitations in the Amazon S3 User Guide.

This field is required.
pub fn set_name(self, input: Option<String>) -> Self

The name of the backup access point. This name is shared with the Amazon S3 access point namespace. It must be unique within your account and Region and cannot conflict with an existing Amazon S3 access point. For more information about access point naming, see Access points naming rules, restrictions, and limitations in the Amazon S3 User Guide.

pub fn get_name(&self) -> &Option<String>

The name of the backup access point. This name is shared with the Amazon S3 access point namespace. It must be unique within your account and Region and cannot conflict with an existing Amazon S3 access point. For more information about access point naming, see Access points naming rules, restrictions, and limitations in the Amazon S3 User Guide.

pub fn recovery_point_arn(self, input: impl Into<String>) -> Self

The Amazon Resource Name (ARN) of the recovery point for which to create the backup access point. The recovery point must be an Amazon S3 recovery point in the AVAILABLE, STOPPED, or COMPLETED state.

This field is required.
pub fn set_recovery_point_arn(self, input: Option<String>) -> Self

The Amazon Resource Name (ARN) of the recovery point for which to create the backup access point. The recovery point must be an Amazon S3 recovery point in the AVAILABLE, STOPPED, or COMPLETED state.

pub fn get_recovery_point_arn(&self) -> &Option<String>

The Amazon Resource Name (ARN) of the recovery point for which to create the backup access point. The recovery point must be an Amazon S3 recovery point in the AVAILABLE, STOPPED, or COMPLETED state.

pub fn tags(self, k: impl Into<String>, v: impl Into<String>) -> Self

Adds a key-value pair to tags.

To override the contents of this collection use set_tags.

The tags to assign to the backup access point.

pub fn set_tags(self, input: Option<HashMap<String, String>>) -> Self

The tags to assign to the backup access point.

pub fn get_tags(&self) -> &Option<HashMap<String, String>>

The tags to assign to the backup access point.

pub fn build(self) -> Result<CreateBackupAccessPointInput, BuildError>

Consumes the builder and constructs a CreateBackupAccessPointInput.

Source

impl CreateBackupAccessPointInputBuilder

pub async fn send_with( self, client: &Client, ) -> Result<CreateBackupAccessPointOutput, SdkError<CreateBackupAccessPointError, HttpResponse>>

Sends a request with this input using the given client.