#[non_exhaustive]pub struct CreateBackupAccessPointInput {
pub access_point_metadata: Option<HashMap<String, String>>,
pub access_point_policy: Option<String>,
pub name: Option<String>,
pub recovery_point_arn: Option<String>,
pub tags: Option<HashMap<String, String>>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.access_point_metadata: Option<HashMap<String, String>>Metadata for the backup access point. For continuous (point-in-time) recovery points, you must include an AccessPointInTime timestamp (in format 2021-11-27T03:30:27Z). The access point provides access to the content present in the backup at that specific time. You can specify any time within the continuous backup's retention period, up to the latest restorable time. For snapshot recovery points, do not include AccessPointInTime.
access_point_policy: Option<String>An optional resource-based policy, in JSON format, to apply to the underlying Amazon S3 access point. The policy controls how backup data can be accessed through the access point. If you do not specify a policy, access is governed by the caller's IAM permissions. For more information, see Configuring IAM policies for using access points in the Amazon S3 User Guide.
name: Option<String>The name of the backup access point. This name is shared with the Amazon S3 access point namespace. It must be unique within your account and Region and cannot conflict with an existing Amazon S3 access point. For more information about access point naming, see Access points naming rules, restrictions, and limitations in the Amazon S3 User Guide.
recovery_point_arn: Option<String>The Amazon Resource Name (ARN) of the recovery point for which to create the backup access point. The recovery point must be an Amazon S3 recovery point in the AVAILABLE, STOPPED, or COMPLETED state.
The tags to assign to the backup access point.
Implementations
Sourceimpl CreateBackupAccessPointInput
impl CreateBackupAccessPointInput
Sourcepub fn access_point_metadata(&self) -> Option<&HashMap<String, String>>
pub fn access_point_metadata(&self) -> Option<&HashMap<String, String>>
Metadata for the backup access point. For continuous (point-in-time) recovery points, you must include an AccessPointInTime timestamp (in format 2021-11-27T03:30:27Z). The access point provides access to the content present in the backup at that specific time. You can specify any time within the continuous backup's retention period, up to the latest restorable time. For snapshot recovery points, do not include AccessPointInTime.
Sourcepub fn access_point_policy(&self) -> Option<&str>
pub fn access_point_policy(&self) -> Option<&str>
An optional resource-based policy, in JSON format, to apply to the underlying Amazon S3 access point. The policy controls how backup data can be accessed through the access point. If you do not specify a policy, access is governed by the caller's IAM permissions. For more information, see Configuring IAM policies for using access points in the Amazon S3 User Guide.
Sourcepub fn name(&self) -> Option<&str>
pub fn name(&self) -> Option<&str>
The name of the backup access point. This name is shared with the Amazon S3 access point namespace. It must be unique within your account and Region and cannot conflict with an existing Amazon S3 access point. For more information about access point naming, see Access points naming rules, restrictions, and limitations in the Amazon S3 User Guide.
Sourcepub fn recovery_point_arn(&self) -> Option<&str>
pub fn recovery_point_arn(&self) -> Option<&str>
The Amazon Resource Name (ARN) of the recovery point for which to create the backup access point. The recovery point must be an Amazon S3 recovery point in the AVAILABLE, STOPPED, or COMPLETED state.
The tags to assign to the backup access point.
Sourceimpl CreateBackupAccessPointInput
impl CreateBackupAccessPointInput
Sourcepub fn builder() -> CreateBackupAccessPointInputBuilder
pub fn builder() -> CreateBackupAccessPointInputBuilder
Creates a new builder-style object to manufacture CreateBackupAccessPointInput.