#[non_exhaustive]pub struct CreateBackupAccessPointOutput {
pub access_point_arn: String,
pub status: AccessPointStatus,
/* private fields */
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.access_point_arn: StringThe Amazon Resource Name (ARN) that uniquely identifies the created backup access point.
status: AccessPointStatusThe current status of the backup access point. A newly created backup access point begins in the CREATING state and becomes usable when it reaches AVAILABLE.
Implementations
Sourceimpl CreateBackupAccessPointOutput
impl CreateBackupAccessPointOutput
Sourcepub fn access_point_arn(&self) -> &str
pub fn access_point_arn(&self) -> &str
The Amazon Resource Name (ARN) that uniquely identifies the created backup access point.
Sourcepub fn status(&self) -> &AccessPointStatus
pub fn status(&self) -> &AccessPointStatus
The current status of the backup access point. A newly created backup access point begins in the CREATING state and becomes usable when it reaches AVAILABLE.
Sourceimpl CreateBackupAccessPointOutput
impl CreateBackupAccessPointOutput
Sourcepub fn builder() -> CreateBackupAccessPointOutputBuilder
pub fn builder() -> CreateBackupAccessPointOutputBuilder
Creates a new builder-style object to manufacture CreateBackupAccessPointOutput.