#[non_exhaustive]pub struct DescribeBackupAccessPointOutput {
pub access_point_arn: String,
pub access_point_metadata: Option<HashMap<String, String>>,
pub backup_vault_arn: Option<String>,
pub backup_vault_name: String,
pub creation_time: DateTime,
pub name: String,
pub recovery_point_arn: String,
pub resource_arn: String,
pub resource_type: String,
pub status: AccessPointStatus,
pub status_message: Option<String>,
/* private fields */
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.access_point_arn: StringThe Amazon Resource Name (ARN) that uniquely identifies the backup access point.
access_point_metadata: Option<HashMap<String, String>>Metadata for the backup access point. After the backup access point reaches the AVAILABLE status, this map contains S3AccessPointArn and S3AccessPointAlias, which you use with standard Amazon S3 read APIs to access the backup data. For continuous recovery points, this map also contains AccessPointInTime (in format 2021-11-27T03:30:27Z). The access point provides access to the content present in the backup at that specific time.
backup_vault_arn: Option<String>The Amazon Resource Name (ARN) of the backup vault that contains the recovery point.
backup_vault_name: StringThe name of the backup vault that contains the recovery point.
creation_time: DateTimeThe date and time that the backup access point was created, in Unix format and Coordinated Universal Time (UTC). The value of CreationTime is accurate to milliseconds. For example, the value 1516925490.087 represents Friday, January 26, 2018 12:11:30.087 AM.
name: StringThe name of the backup access point.
recovery_point_arn: StringThe Amazon Resource Name (ARN) of the recovery point that the backup access point provides access to.
resource_arn: StringThe Amazon Resource Name (ARN) of the resource that was backed up, such as an Amazon S3 bucket.
resource_type: StringThe type of Amazon Web Services resource associated with the recovery point. For example, S3 for Amazon Simple Storage Service.
status: AccessPointStatusThe current status of the backup access point.
status_message: Option<String>A message that provides additional detail about the status of the backup access point, such as the reason a creation or deletion attempt failed.
Implementations
Sourceimpl DescribeBackupAccessPointOutput
impl DescribeBackupAccessPointOutput
Sourcepub fn access_point_arn(&self) -> &str
pub fn access_point_arn(&self) -> &str
The Amazon Resource Name (ARN) that uniquely identifies the backup access point.
Sourcepub fn access_point_metadata(&self) -> Option<&HashMap<String, String>>
pub fn access_point_metadata(&self) -> Option<&HashMap<String, String>>
Metadata for the backup access point. After the backup access point reaches the AVAILABLE status, this map contains S3AccessPointArn and S3AccessPointAlias, which you use with standard Amazon S3 read APIs to access the backup data. For continuous recovery points, this map also contains AccessPointInTime (in format 2021-11-27T03:30:27Z). The access point provides access to the content present in the backup at that specific time.
Sourcepub fn backup_vault_arn(&self) -> Option<&str>
pub fn backup_vault_arn(&self) -> Option<&str>
The Amazon Resource Name (ARN) of the backup vault that contains the recovery point.
Sourcepub fn backup_vault_name(&self) -> &str
pub fn backup_vault_name(&self) -> &str
The name of the backup vault that contains the recovery point.
Sourcepub fn creation_time(&self) -> &DateTime
pub fn creation_time(&self) -> &DateTime
The date and time that the backup access point was created, in Unix format and Coordinated Universal Time (UTC). The value of CreationTime is accurate to milliseconds. For example, the value 1516925490.087 represents Friday, January 26, 2018 12:11:30.087 AM.
Sourcepub fn recovery_point_arn(&self) -> &str
pub fn recovery_point_arn(&self) -> &str
The Amazon Resource Name (ARN) of the recovery point that the backup access point provides access to.
Sourcepub fn resource_arn(&self) -> &str
pub fn resource_arn(&self) -> &str
The Amazon Resource Name (ARN) of the resource that was backed up, such as an Amazon S3 bucket.
Sourcepub fn resource_type(&self) -> &str
pub fn resource_type(&self) -> &str
The type of Amazon Web Services resource associated with the recovery point. For example, S3 for Amazon Simple Storage Service.
Sourcepub fn status(&self) -> &AccessPointStatus
pub fn status(&self) -> &AccessPointStatus
The current status of the backup access point.
Sourcepub fn status_message(&self) -> Option<&str>
pub fn status_message(&self) -> Option<&str>
A message that provides additional detail about the status of the backup access point, such as the reason a creation or deletion attempt failed.
Sourceimpl DescribeBackupAccessPointOutput
impl DescribeBackupAccessPointOutput
Sourcepub fn builder() -> DescribeBackupAccessPointOutputBuilder
pub fn builder() -> DescribeBackupAccessPointOutputBuilder
Creates a new builder-style object to manufacture DescribeBackupAccessPointOutput.