#[non_exhaustive]pub struct ListBackupAccessPointsOutput {
pub backup_access_points: Vec<ListAccessPointsMember>,
pub next_token: Option<String>,
/* private fields */
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.backup_access_points: Vec<ListAccessPointsMember>A list of backup access points, each containing metadata such as its name, ARN, status, and associated recovery point.
next_token: Option<String>The next item following a partial list of returned items. For example, if a request is made to return MaxResults number of items, NextToken allows you to return more items in your list starting at the location pointed to by the next token.
Implementations
Sourceimpl ListBackupAccessPointsOutput
impl ListBackupAccessPointsOutput
Sourcepub fn backup_access_points(&self) -> &[ListAccessPointsMember]
pub fn backup_access_points(&self) -> &[ListAccessPointsMember]
A list of backup access points, each containing metadata such as its name, ARN, status, and associated recovery point.
Sourcepub fn next_token(&self) -> Option<&str>
pub fn next_token(&self) -> Option<&str>
The next item following a partial list of returned items. For example, if a request is made to return MaxResults number of items, NextToken allows you to return more items in your list starting at the location pointed to by the next token.
Sourceimpl ListBackupAccessPointsOutput
impl ListBackupAccessPointsOutput
Sourcepub fn builder() -> ListBackupAccessPointsOutputBuilder
pub fn builder() -> ListBackupAccessPointsOutputBuilder
Creates a new builder-style object to manufacture ListBackupAccessPointsOutput.