Struct aws_sdk_backup::output::DescribeReportJobOutput [−][src]
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.report_job: Option<ReportJob>A list of information about a report job, including its completion and creation times, report destination, unique report job ID, Amazon Resource Name (ARN), report template, status, and status message.
Implementations
A list of information about a report job, including its completion and creation times, report destination, unique report job ID, Amazon Resource Name (ARN), report template, status, and status message.
Creates a new builder-style object to manufacture DescribeReportJobOutput