Struct aws_sdk_backup::output::GetRecoveryPointRestoreMetadataOutput [−][src]
#[non_exhaustive]pub struct GetRecoveryPointRestoreMetadataOutput {
pub backup_vault_arn: Option<String>,
pub recovery_point_arn: Option<String>,
pub restore_metadata: Option<HashMap<String, String>>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.backup_vault_arn: Option<String>An ARN that uniquely identifies a backup vault; for example,
arn:aws:backup:us-east-1:123456789012:vault:aBackupVault.
recovery_point_arn: Option<String>An ARN that uniquely identifies a recovery point; for example,
arn:aws:backup:us-east-1:123456789012:recovery-point:1EB3B5E7-9EB0-435A-A80B-108B488B0D45.
restore_metadata: Option<HashMap<String, String>>The set of metadata key-value pairs that describe the original configuration of the backed-up resource. These values vary depending on the service that is being restored.
Implementations
An ARN that uniquely identifies a backup vault; for example,
arn:aws:backup:us-east-1:123456789012:vault:aBackupVault.
An ARN that uniquely identifies a recovery point; for example,
arn:aws:backup:us-east-1:123456789012:recovery-point:1EB3B5E7-9EB0-435A-A80B-108B488B0D45.
Creates a new builder-style object to manufacture GetRecoveryPointRestoreMetadataOutput