Struct aws_sdk_backup::output::GetSupportedResourceTypesOutput [−][src]
#[non_exhaustive]pub struct GetSupportedResourceTypesOutput {
pub resource_types: Option<Vec<String>>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.resource_types: Option<Vec<String>>Contains a string with the supported Amazon Web Services resource types:
-
Aurorafor Amazon Aurora -
DynamoDBfor Amazon DynamoDB -
EBSfor Amazon Elastic Block Store -
EC2for Amazon Elastic Compute Cloud -
EFSfor Amazon Elastic File System -
FSXfor Amazon FSx -
RDSfor Amazon Relational Database Service -
Storage Gatewayfor Storage Gateway
Implementations
Contains a string with the supported Amazon Web Services resource types:
-
Aurorafor Amazon Aurora -
DynamoDBfor Amazon DynamoDB -
EBSfor Amazon Elastic Block Store -
EC2for Amazon Elastic Compute Cloud -
EFSfor Amazon Elastic File System -
FSXfor Amazon FSx -
RDSfor Amazon Relational Database Service -
Storage Gatewayfor Storage Gateway
Creates a new builder-style object to manufacture GetSupportedResourceTypesOutput