Struct aws_sdk_backup::output::ListBackupJobsOutput [−][src]
#[non_exhaustive]pub struct ListBackupJobsOutput {
pub backup_jobs: Option<Vec<BackupJob>>,
pub next_token: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.backup_jobs: Option<Vec<BackupJob>>An array of structures containing metadata about your backup jobs returned in JSON format.
next_token: Option<String>The next item following a partial list of returned items. For example, if a request is
made to return maxResults number of items, NextToken allows you
to return more items in your list starting at the location pointed to by the next
token.
Implementations
An array of structures containing metadata about your backup jobs returned in JSON format.
The next item following a partial list of returned items. For example, if a request is
made to return maxResults number of items, NextToken allows you
to return more items in your list starting at the location pointed to by the next
token.
Creates a new builder-style object to manufacture ListBackupJobsOutput