Struct aws_sdk_backup::output::ListBackupPlanTemplatesOutput [−][src]
#[non_exhaustive]pub struct ListBackupPlanTemplatesOutput {
pub next_token: Option<String>,
pub backup_plan_templates_list: Option<Vec<BackupPlanTemplatesListMember>>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.next_token: Option<String>The next item following a partial list of returned items. For example, if a request is
made to return maxResults number of items, NextToken allows you
to return more items in your list starting at the location pointed to by the next
token.
backup_plan_templates_list: Option<Vec<BackupPlanTemplatesListMember>>An array of template list items containing metadata about your saved templates.
Implementations
The next item following a partial list of returned items. For example, if a request is
made to return maxResults number of items, NextToken allows you
to return more items in your list starting at the location pointed to by the next
token.
An array of template list items containing metadata about your saved templates.
Creates a new builder-style object to manufacture ListBackupPlanTemplatesOutput