Struct aws_sdk_backup::output::ListRecoveryPointsByResourceOutput [−][src]
#[non_exhaustive]pub struct ListRecoveryPointsByResourceOutput {
pub next_token: Option<String>,
pub recovery_points: Option<Vec<RecoveryPointByResource>>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.next_token: Option<String>The next item following a partial list of returned items. For example, if a request is
made to return maxResults number of items, NextToken allows you
to return more items in your list starting at the location pointed to by the next
token.
recovery_points: Option<Vec<RecoveryPointByResource>>An array of objects that contain detailed information about recovery points of the specified resource type.
Only Amazon EFS and Amazon EC2 recovery points return BackupVaultName.
Implementations
The next item following a partial list of returned items. For example, if a request is
made to return maxResults number of items, NextToken allows you
to return more items in your list starting at the location pointed to by the next
token.
An array of objects that contain detailed information about recovery points of the specified resource type.
Only Amazon EFS and Amazon EC2 recovery points return BackupVaultName.
Creates a new builder-style object to manufacture ListRecoveryPointsByResourceOutput