Struct aws_sdk_backup::output::ListReportJobsOutput [−][src]
#[non_exhaustive]pub struct ListReportJobsOutput {
pub report_jobs: Option<Vec<ReportJob>>,
pub next_token: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.report_jobs: Option<Vec<ReportJob>>Details about your report jobs in JSON format.
next_token: Option<String>An identifier that was returned from the previous call to this operation, which can be used to return the next set of items in the list.
Implementations
Details about your report jobs in JSON format.
An identifier that was returned from the previous call to this operation, which can be used to return the next set of items in the list.
Creates a new builder-style object to manufacture ListReportJobsOutput