Struct aws_sdk_backup::output::ListRestoreJobsOutput [−][src]
#[non_exhaustive]pub struct ListRestoreJobsOutput {
pub restore_jobs: Option<Vec<RestoreJobsListMember>>,
pub next_token: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.restore_jobs: Option<Vec<RestoreJobsListMember>>An array of objects that contain detailed information about jobs to restore saved resources.
next_token: Option<String>The next item following a partial list of returned items. For example, if a request is
made to return maxResults number of items, NextToken allows you
to return more items in your list starting at the location pointed to by the next
token.
Implementations
An array of objects that contain detailed information about jobs to restore saved resources.
The next item following a partial list of returned items. For example, if a request is
made to return maxResults number of items, NextToken allows you
to return more items in your list starting at the location pointed to by the next
token.
Creates a new builder-style object to manufacture ListRestoreJobsOutput